@@ -134,6 +134,11 @@ module Cinch
       !attr(:authname).nil?
     end
 
+    # @see Syncable#attr
+    def attr(attribute, data = true, unsync = false)
+      super
+    end
+
     # Queries the IRC server for information on the user. This will
     # set the User's state to not synced. After all information are
     # received, the object will be set back to synced.
@@ -194,6 +199,7 @@ module Cinch
         :authname => nil,
         :idle => 0,
         :secure? => false,
+        :channels => [],
       }.merge(values).each do |attr, value|
         sync(attr, value, true)
       end
@@ -272,7 +278,8 @@ module Cinch
         refresh
         @monitored_timer = Timer.new(@bot, interval: 30) {
           refresh
-        }.start
+        }
+        @monitored_timer.start
       end
 
       @monitored = true
